import { Observable } from 'rxjs';
import { Evolution } from './evolution';
import { Lens } from './lens';
declare type Evolver<A> = (evolution: Evolution<A>) => void;
/**
 * A stateful container that exposing a stream of state values that users can subscribe to.
 *
 * A Telescope is an endo-profunctor for a type U which means it accepts new U values and
 * produces U values on the associated stream.
 */
export declare class Telescope<U> {
    private readonly evolver;
    static of<U>(initialState: U): Telescope<U>;
    readonly stream: Observable<U>;
    constructor(evolver: Evolver<U>, stream: Observable<U>);
    dimap<P>(to: (u: U) => P, from: (p: P) => U): Telescope<P>;
    uplift<C>(value: C): Telescope<{
        first: U;
        second: C;
    }>;
    evolve(evolution: Evolution<U>): void;
    update(newState: U): void;
    magnify<P>(lens: Lens<U, P>): Telescope<P>;
}
export {};
